16.5. cdist-type__apt_mark(7) — cdist 6.1.1 documentation

# 16.5. cdist-type__apt_mark(7)

## 16.5.1. NAME

cdist-type__apt_mark - set package state as 'hold' or 'unhold'

## 16.5.2. DESCRIPTION

See apt-mark(8) for details.

## 16.5.3. REQUIRED PARAMETERS

state
  Either "hold" or "unhold".

## 16.5.4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.

## 16.5.5. EXAMPLES

    # hold package
    __apt_mark quagga --state hold
    # unhold package
    __apt_mark quagga --state unhold

## 16.5.6. AUTHORS

Ander Punnar <cdist--@--kvlt.ee>

## 16.5.7. COPYING

Copyright (C) 2016 Ander Punnar. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.